API Reference
=============

Directory layout
----------------

.. autoclass:: dirlay.DirLayout
    :members:
    :special-members: __contains__, __eq__, __getitem__, __iter__, __or__, __ior__, __enter__, __exit__

Formatting
----------

.. autofunction:: dirlay.format_rich.to_tree
